==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
export let WebGridToolbarHidingDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarHidingDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarHidingDescriptionMetadata.a == null) {
                WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
            }
            if (a.j(WebGridToolbarHidingDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridToolbarHidingDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarHiding");
            a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarHidingDescriptionMetadata.b(a);
            a.aa("WebGridToolbarHiding", () => new WebGridToolbarHidingDescription());
            a.z("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
        }
    }
    WebGridToolbarHidingDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
export let WebGridToolbarHidingDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarHidingDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarHidingDescriptionMetadata.a == null) {
                WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarHidingDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridToolbarHidingDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarHiding");
            a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("__manageItemInMarkup", "Boolean");
        }
        static d(a) {
            WebGridToolbarHidingDescriptionMetadata.b(a);
            a.ac("WebGridToolbarHiding", () => new WebGridToolbarHidingDescription());
            a.ab("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
        }
    }
    WebGridToolbarHidingDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
})();
